Description Usage Arguments Details Value Examples
Computes running sample standard deviation of a sequence in a fixed width window. Uses convolution implementation via Fast Fourier Transform.
1 |
x |
A numeric vector. |
W |
A numeric scalar; width of |
circular |
Logical; whether running sample standard deviation is computed assuming
circular nature of |
The length of output vector equals the length of x vector.
Parameter circular determines whether x sequence is assumed to have a circular nature.
Assume l_x is the length of sequence x, W is a fixed length of x sequence window.
If circular equals TRUE then
first element of the output sequence corresponds to sample standard deviation of x[1:W],
last element of the output sequence corresponds to sample standard deviation of c(x[l_x], x[1:(W - 1)]).
If circular equals FALSE then
first element of the output sequence corresponds to sample standard deviation of x[1:W],
the l_x - W + 1-th element of the output sequence corresponds to sample standard deviation of x[(l_x - W + 1):l_x],
last W-1 elements of the output sequence are filled with NA.
A numeric vector.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.